Class: Bandwidth::CreateEndpointResponseData

Inherits:
ApiModelBase show all
Defined in:
lib/bandwidth-sdk/models/create_endpoint_response_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateEndpointResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::CreateEndpointResponseData` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::CreateEndpointResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'endpoint_id')
    self.endpoint_id = attributes[:'endpoint_id']
  else
    self.endpoint_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'creation_timestamp')
    self.creation_timestamp = attributes[:'creation_timestamp']
  else
    self.creation_timestamp = nil
  end

  if attributes.key?(:'expiration_timestamp')
    self.expiration_timestamp = attributes[:'expiration_timestamp']
  else
    self.expiration_timestamp = nil
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'devices')
    if (value = attributes[:'devices']).is_a?(Array)
      self.devices = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end
end

Instance Attribute Details

#creation_timestampObject

The time the endpoint was created. In ISO-8601 format.



26
27
28
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 26

def creation_timestamp
  @creation_timestamp
end

#devicesObject

Returns the value of attribute devices.



34
35
36
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 34

def devices
  @devices
end

#endpoint_idObject

The unique ID of the endpoint.



19
20
21
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 19

def endpoint_id
  @endpoint_id
end

#expiration_timestampObject

The time the endpoint token will expire. In ISO-8601 format. Tokens last 24 hours.



29
30
31
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 29

def expiration_timestamp
  @expiration_timestamp
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 23

def status
  @status
end

#tagObject

A tag for the endpoint.



32
33
34
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 32

def tag
  @tag
end

#tokenObject

The json web token specific to the endpoint. Used to authenticate the client with the media gateway.



37
38
39
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 37

def token
  @token
end

#typeObject

Returns the value of attribute type.



21
22
23
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 21

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 62

def self.attribute_map
  {
    :'endpoint_id' => :'endpointId',
    :'type' => :'type',
    :'status' => :'status',
    :'creation_timestamp' => :'creationTimestamp',
    :'expiration_timestamp' => :'expirationTimestamp',
    :'tag' => :'tag',
    :'devices' => :'devices',
    :'token' => :'token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



106
107
108
109
110
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 106

def self.openapi_all_of
  [
  :'Endpoint'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 86

def self.openapi_types
  {
    :'endpoint_id' => :'String',
    :'type' => :'EndpointTypeEnum',
    :'status' => :'EndpointStatusEnum',
    :'creation_timestamp' => :'Time',
    :'expiration_timestamp' => :'Time',
    :'tag' => :'String',
    :'devices' => :'Array<Device>',
    :'token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      endpoint_id == o.endpoint_id &&
      type == o.type &&
      status == o.status &&
      creation_timestamp == o.creation_timestamp &&
      expiration_timestamp == o.expiration_timestamp &&
      tag == o.tag &&
      devices == o.devices &&
      token == o.token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 313

def hash
  [endpoint_id, type, status, creation_timestamp, expiration_timestamp, tag, devices, token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @endpoint_id.nil?
    invalid_properties.push('invalid value for "endpoint_id", endpoint_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @creation_timestamp.nil?
    invalid_properties.push('invalid value for "creation_timestamp", creation_timestamp cannot be nil.')
  end

  if @expiration_timestamp.nil?
    invalid_properties.push('invalid value for "expiration_timestamp", expiration_timestamp cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
218
# File 'lib/bandwidth-sdk/models/create_endpoint_response_data.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @endpoint_id.nil?
  return false if @type.nil?
  return false if @status.nil?
  return false if @creation_timestamp.nil?
  return false if @expiration_timestamp.nil?
  return false if @token.nil?
  true
end