Class: Bandwidth::CreateWebRtcConnectionRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateWebRtcConnectionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::CreateWebRtcConnectionRequest` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::CreateWebRtcConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end

  if attributes.key?(:'event_callback_url')
    self.event_callback_url = attributes[:'event_callback_url']
  end

  if attributes.key?(:'event_fallback_url')
    self.event_fallback_url = attributes[:'event_fallback_url']
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'connection_metadata')
    self. = attributes[:'connection_metadata']
  end
end

Instance Attribute Details

#connection_metadataObject

Returns the value of attribute connection_metadata.



31
32
33
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 31

def 
  @connection_metadata
end

#directionObject

Returns the value of attribute direction.



20
21
22
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 20

def direction
  @direction
end

#event_callback_urlObject

The URL to send event callbacks to.



23
24
25
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 23

def event_callback_url
  @event_callback_url
end

#event_fallback_urlObject

The URL to send event fallbacks to.



26
27
28
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 26

def event_fallback_url
  @event_fallback_url
end

#tagObject

A tag for the endpoint.



29
30
31
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 29

def tag
  @tag
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 56

def self.attribute_map
  {
    :'type' => :'type',
    :'direction' => :'direction',
    :'event_callback_url' => :'eventCallbackUrl',
    :'event_fallback_url' => :'eventFallbackUrl',
    :'tag' => :'tag',
    :'connection_metadata' => :'connectionMetadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 230

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



96
97
98
99
100
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 96

def self.openapi_all_of
  [
  :'CreateEndpointRequestBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 78

def self.openapi_types
  {
    :'type' => :'EndpointTypeEnum',
    :'direction' => :'EndpointDirectionEnum',
    :'event_callback_url' => :'String',
    :'event_fallback_url' => :'String',
    :'tag' => :'String',
    :'connection_metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      direction == o.direction &&
      event_callback_url == o.event_callback_url &&
      event_fallback_url == o.event_fallback_url &&
      tag == o.tag &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 223

def hash
  [type, direction, event_callback_url, event_fallback_url, tag, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
# File 'lib/bandwidth-sdk/models/create_web_rtc_connection_request.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if @direction.nil?
  true
end