Class: Bandwidth::Endpoints

Inherits:
ApiModelBase show all
Defined in:
lib/bandwidth-sdk/models/endpoints.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Endpoints

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::Endpoints` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::Endpoints`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'endpoint_id')
    self.endpoint_id = attributes[:'endpoint_id']
  else
    self.endpoint_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'creation_timestamp')
    self.creation_timestamp = attributes[:'creation_timestamp']
  else
    self.creation_timestamp = nil
  end

  if attributes.key?(:'expiration_timestamp')
    self.expiration_timestamp = attributes[:'expiration_timestamp']
  else
    self.expiration_timestamp = nil
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end
end

Instance Attribute Details

#creation_timestampObject

The time the endpoint was created. In ISO-8601 format.



26
27
28
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 26

def creation_timestamp
  @creation_timestamp
end

#endpoint_idObject

The unique ID of the endpoint.



19
20
21
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 19

def endpoint_id
  @endpoint_id
end

#expiration_timestampObject

The time the endpoint token will expire. In ISO-8601 format. Tokens last 24 hours.



29
30
31
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 29

def expiration_timestamp
  @expiration_timestamp
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 23

def status
  @status
end

#tagObject

A tag for the endpoint.



32
33
34
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 32

def tag
  @tag
end

#typeObject

Returns the value of attribute type.



21
22
23
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 21

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 57

def self.attribute_map
  {
    :'endpoint_id' => :'endpointId',
    :'type' => :'type',
    :'status' => :'status',
    :'creation_timestamp' => :'creationTimestamp',
    :'expiration_timestamp' => :'expirationTimestamp',
    :'tag' => :'tag'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 79

def self.openapi_types
  {
    :'endpoint_id' => :'String',
    :'type' => :'EndpointTypeEnum',
    :'status' => :'EndpointStatusEnum',
    :'creation_timestamp' => :'Time',
    :'expiration_timestamp' => :'Time',
    :'tag' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      endpoint_id == o.endpoint_id &&
      type == o.type &&
      status == o.status &&
      creation_timestamp == o.creation_timestamp &&
      expiration_timestamp == o.expiration_timestamp &&
      tag == o.tag
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 268

def hash
  [endpoint_id, type, status, creation_timestamp, expiration_timestamp, tag].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @endpoint_id.nil?
    invalid_properties.push('invalid value for "endpoint_id", endpoint_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @creation_timestamp.nil?
    invalid_properties.push('invalid value for "creation_timestamp", creation_timestamp cannot be nil.')
  end

  if @expiration_timestamp.nil?
    invalid_properties.push('invalid value for "expiration_timestamp", expiration_timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
185
# File 'lib/bandwidth-sdk/models/endpoints.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @endpoint_id.nil?
  return false if @type.nil?
  return false if @status.nil?
  return false if @creation_timestamp.nil?
  return false if @expiration_timestamp.nil?
  true
end