Class: Bandwidth::EndpointsApi
- Inherits:
-
Object
- Object
- Bandwidth::EndpointsApi
- Defined in:
- lib/bandwidth-sdk/api/endpoints_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_endpoint(account_id, body, opts = {}) ⇒ CreateEndpointResponse
Create Endpoint Creates a new Endpoint for the specified account.
-
#create_endpoint_with_http_info(account_id, body, opts = {}) ⇒ Array<(CreateEndpointResponse, Integer, Hash)>
Create Endpoint Creates a new Endpoint for the specified account.
-
#delete_endpoint(account_id, endpoint_id, opts = {}) ⇒ nil
Delete Endpoint Deletes the specified endpoint.
-
#delete_endpoint_with_http_info(account_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Endpoint Deletes the specified endpoint.
-
#get_endpoint(account_id, endpoint_id, opts = {}) ⇒ EndpointResponse
Get Endpoint Returns information about the specified endpoint.
-
#get_endpoint_with_http_info(account_id, endpoint_id, opts = {}) ⇒ Array<(EndpointResponse, Integer, Hash)>
Get Endpoint Returns information about the specified endpoint.
-
#initialize(api_client = ApiClient.default) ⇒ EndpointsApi
constructor
A new instance of EndpointsApi.
-
#list_endpoints(account_id, opts = {}) ⇒ ListEndpointsResponse
List Endpoints Returns a list of endpoints associated with the specified account.
-
#list_endpoints_with_http_info(account_id, opts = {}) ⇒ Array<(ListEndpointsResponse, Integer, Hash)>
List Endpoints Returns a list of endpoints associated with the specified account.
-
#update_endpoint_bxml(account_id, endpoint_id, body, opts = {}) ⇒ nil
Update Endpoint BXML Updates the BXML for the specified endpoint.
-
#update_endpoint_bxml_with_http_info(account_id, endpoint_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Endpoint BXML Updates the BXML for the specified endpoint.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EndpointsApi
Returns a new instance of EndpointsApi.
19 20 21 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_endpoint(account_id, body, opts = {}) ⇒ CreateEndpointResponse
Create Endpoint Creates a new Endpoint for the specified account.
28 29 30 31 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 28 def create_endpoint(account_id, body, opts = {}) data, _status_code, _headers = create_endpoint_with_http_info(account_id, body, opts) data end |
#create_endpoint_with_http_info(account_id, body, opts = {}) ⇒ Array<(CreateEndpointResponse, Integer, Hash)>
Create Endpoint Creates a new Endpoint for the specified account.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 39 def create_endpoint_with_http_info(account_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.create_endpoint ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling EndpointsApi.create_endpoint" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling EndpointsApi.create_endpoint" end # resource path local_var_path = '/accounts/{accountId}/endpoints'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'CreateEndpointResponse' # auth_names auth_names = opts[:debug_auth_names] || ['Basic', 'OAuth2'] = opts.merge( :operation => :"EndpointsApi.create_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#create_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_endpoint(account_id, endpoint_id, opts = {}) ⇒ nil
Delete Endpoint Deletes the specified endpoint. If the endpoint is actively streaming media, the media stream will be terminated.
102 103 104 105 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 102 def delete_endpoint(account_id, endpoint_id, opts = {}) delete_endpoint_with_http_info(account_id, endpoint_id, opts) nil end |
#delete_endpoint_with_http_info(account_id, endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Endpoint Deletes the specified endpoint. If the endpoint is actively streaming media, the media stream will be terminated.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 113 def delete_endpoint_with_http_info(account_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.delete_endpoint ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling EndpointsApi.delete_endpoint" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling EndpointsApi.delete_endpoint" end # resource path local_var_path = '/accounts/{accountId}/endpoints/{endpointId}'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Basic', 'OAuth2'] = opts.merge( :operation => :"EndpointsApi.delete_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#delete_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_endpoint(account_id, endpoint_id, opts = {}) ⇒ EndpointResponse
Get Endpoint Returns information about the specified endpoint.
171 172 173 174 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 171 def get_endpoint(account_id, endpoint_id, opts = {}) data, _status_code, _headers = get_endpoint_with_http_info(account_id, endpoint_id, opts) data end |
#get_endpoint_with_http_info(account_id, endpoint_id, opts = {}) ⇒ Array<(EndpointResponse, Integer, Hash)>
Get Endpoint Returns information about the specified endpoint.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 182 def get_endpoint_with_http_info(account_id, endpoint_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.get_endpoint ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling EndpointsApi.get_endpoint" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling EndpointsApi.get_endpoint" end # resource path local_var_path = '/accounts/{accountId}/endpoints/{endpointId}'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EndpointResponse' # auth_names auth_names = opts[:debug_auth_names] || ['Basic', 'OAuth2'] = opts.merge( :operation => :"EndpointsApi.get_endpoint", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#get_endpoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_endpoints(account_id, opts = {}) ⇒ ListEndpointsResponse
List Endpoints Returns a list of endpoints associated with the specified account.
243 244 245 246 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 243 def list_endpoints(account_id, opts = {}) data, _status_code, _headers = list_endpoints_with_http_info(account_id, opts) data end |
#list_endpoints_with_http_info(account_id, opts = {}) ⇒ Array<(ListEndpointsResponse, Integer, Hash)>
List Endpoints Returns a list of endpoints associated with the specified account.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 257 def list_endpoints_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.list_endpoints ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling EndpointsApi.list_endpoints" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EndpointsApi.list_endpoints, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EndpointsApi.list_endpoints, must be greater than or equal to 1.' end # resource path local_var_path = '/accounts/{accountId}/endpoints'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'afterCursor'] = opts[:'after_cursor'] if !opts[:'after_cursor'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListEndpointsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['Basic', 'OAuth2'] = opts.merge( :operation => :"EndpointsApi.list_endpoints", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#list_endpoints\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_endpoint_bxml(account_id, endpoint_id, body, opts = {}) ⇒ nil
Update Endpoint BXML Updates the BXML for the specified endpoint.
324 325 326 327 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 324 def update_endpoint_bxml(account_id, endpoint_id, body, opts = {}) update_endpoint_bxml_with_http_info(account_id, endpoint_id, body, opts) nil end |
#update_endpoint_bxml_with_http_info(account_id, endpoint_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Endpoint BXML Updates the BXML for the specified endpoint.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/bandwidth-sdk/api/endpoints_api.rb', line 336 def update_endpoint_bxml_with_http_info(account_id, endpoint_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.update_endpoint_bxml ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling EndpointsApi.update_endpoint_bxml" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling EndpointsApi.update_endpoint_bxml" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling EndpointsApi.update_endpoint_bxml" end # resource path local_var_path = '/accounts/{accountId}/endpoints/{endpointId}/bxml'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)).sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/xml']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Basic', 'OAuth2'] = opts.merge( :operation => :"EndpointsApi.update_endpoint_bxml", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#update_endpoint_bxml\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |