Method: Bandwidth::HttpClient#execute_as_string
- Defined in:
- lib/bandwidth/http/http_client.rb
#execute_as_string(_http_request) ⇒ Object
Execute an HttpRequest when the response is expected to be a string.
14 15 16 17 |
# File 'lib/bandwidth/http/http_client.rb', line 14 def execute_as_string(_http_request) raise NotImplementedError, 'This method needs to be implemented in a child class.' end |