Class: Bandwidth::RbmStandaloneCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Bandwidth::RbmStandaloneCard
- Defined in:
- lib/bandwidth-sdk/models/rbm_standalone_card.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#card_content ⇒ Object
Returns the value of attribute card_content.
-
#orientation ⇒ Object
Returns the value of attribute orientation.
-
#suggestions ⇒ Object
An array of suggested actions for the recipient.
-
#thumbnail_image_alignment ⇒ Object
Returns the value of attribute thumbnail_image_alignment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RbmStandaloneCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RbmStandaloneCard
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::RbmStandaloneCard` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::RbmStandaloneCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'orientation') self.orientation = attributes[:'orientation'] else self.orientation = nil end if attributes.key?(:'thumbnail_image_alignment') self.thumbnail_image_alignment = attributes[:'thumbnail_image_alignment'] end if attributes.key?(:'card_content') self.card_content = attributes[:'card_content'] else self.card_content = nil end if attributes.key?(:'suggestions') if (value = attributes[:'suggestions']).is_a?(Array) self.suggestions = value end end end |
Instance Attribute Details
#card_content ⇒ Object
Returns the value of attribute card_content.
22 23 24 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 22 def card_content @card_content end |
#orientation ⇒ Object
Returns the value of attribute orientation.
18 19 20 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 18 def orientation @orientation end |
#suggestions ⇒ Object
An array of suggested actions for the recipient.
25 26 27 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 25 def suggestions @suggestions end |
#thumbnail_image_alignment ⇒ Object
Returns the value of attribute thumbnail_image_alignment.
20 21 22 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 20 def thumbnail_image_alignment @thumbnail_image_alignment end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 50 def self.attribute_map { :'orientation' => :'orientation', :'thumbnail_image_alignment' => :'thumbnailImageAlignment', :'card_content' => :'cardContent', :'suggestions' => :'suggestions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 70 def self.openapi_types { :'orientation' => :'StandaloneCardOrientationEnum', :'thumbnail_image_alignment' => :'ThumbnailAlignmentEnum', :'card_content' => :'RbmCardContent', :'suggestions' => :'Array<MultiChannelAction>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && orientation == o.orientation && thumbnail_image_alignment == o.thumbnail_image_alignment && card_content == o.card_content && suggestions == o.suggestions end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 207 def hash [orientation, thumbnail_image_alignment, card_content, suggestions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @orientation.nil? invalid_properties.push('invalid value for "orientation", orientation cannot be nil.') end if @card_content.nil? invalid_properties.push('invalid value for "card_content", card_content cannot be nil.') end if !@suggestions.nil? && @suggestions.length > 11 invalid_properties.push('invalid value for "suggestions", number of items must be less than or equal to 11.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 |
# File 'lib/bandwidth-sdk/models/rbm_standalone_card.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @orientation.nil? return false if @card_content.nil? return false if !@suggestions.nil? && @suggestions.length > 11 true end |