Class: Bandwidth::RbmSuggestionResponse

Inherits:
ApiModelBase show all
Defined in:
lib/bandwidth-sdk/models/rbm_suggestion_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RbmSuggestionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::RbmSuggestionResponse` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::RbmSuggestionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'postback_data')
    self.postback_data = attributes[:'postback_data']
  end

  if attributes.key?(:'paired_message_id')
    self.paired_message_id = attributes[:'paired_message_id']
  end
end

Instance Attribute Details

#paired_message_idObject

Corresponding parent message ID (MT).



25
26
27
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 25

def paired_message_id
  @paired_message_id
end

#postback_dataObject

Base64 payload the customer receives when the reply is clicked.



22
23
24
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 22

def postback_data
  @postback_data
end

#textObject

The text associated with the suggestion response.



19
20
21
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 19

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 28

def self.attribute_map
  {
    :'text' => :'text',
    :'postback_data' => :'postbackData',
    :'paired_message_id' => :'pairedMessageId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 150

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
60
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 56

def self.openapi_nullable
  Set.new([
    :'paired_message_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 47

def self.openapi_types
  {
    :'text' => :'String',
    :'postback_data' => :'String',
    :'paired_message_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
132
133
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      text == o.text &&
      postback_data == o.postback_data &&
      paired_message_id == o.paired_message_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


137
138
139
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 137

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



143
144
145
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 143

def hash
  [text, postback_data, paired_message_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



93
94
95
96
97
98
99
100
101
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 93

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@postback_data.nil? && @postback_data.to_s.length > 2048
    invalid_properties.push('invalid value for "postback_data", the character length must be smaller than or equal to 2048.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 172

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



105
106
107
108
109
# File 'lib/bandwidth-sdk/models/rbm_suggestion_response.rb', line 105

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@postback_data.nil? && @postback_data.to_s.length > 2048
  true
end