Class: Bandwidth::RecordingTranscriptionClip
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Bandwidth::RecordingTranscriptionClip
- Defined in:
- lib/bandwidth-sdk/models/recording_transcription_clip.rb
Instance Attribute Summary collapse
-
#confidence ⇒ Object
How confident the transcription engine was in transcribing this clip (from ‘0.0` to `1.0`).
-
#end_time_seconds ⇒ Object
The end time of this clip within the recording, in seconds.
-
#speaker ⇒ Object
Zero-based index identifying the speaker.
-
#start_time_seconds ⇒ Object
The start time of this clip within the recording, in seconds.
-
#text ⇒ Object
The transcribed text of this clip.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecordingTranscriptionClip
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RecordingTranscriptionClip
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::RecordingTranscriptionClip` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::RecordingTranscriptionClip`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'speaker') self.speaker = attributes[:'speaker'] end if attributes.key?(:'text') self.text = attributes[:'text'] end if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] end if attributes.key?(:'start_time_seconds') self.start_time_seconds = attributes[:'start_time_seconds'] end if attributes.key?(:'end_time_seconds') self.end_time_seconds = attributes[:'end_time_seconds'] end end |
Instance Attribute Details
#confidence ⇒ Object
How confident the transcription engine was in transcribing this clip (from ‘0.0` to `1.0`).
25 26 27 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 25 def confidence @confidence end |
#end_time_seconds ⇒ Object
The end time of this clip within the recording, in seconds.
31 32 33 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 31 def end_time_seconds @end_time_seconds end |
#speaker ⇒ Object
Zero-based index identifying the speaker.
19 20 21 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 19 def speaker @speaker end |
#start_time_seconds ⇒ Object
The start time of this clip within the recording, in seconds.
28 29 30 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 28 def start_time_seconds @start_time_seconds end |
#text ⇒ Object
The transcribed text of this clip.
22 23 24 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 22 def text @text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 34 def self.attribute_map { :'speaker' => :'speaker', :'text' => :'text', :'confidence' => :'confidence', :'start_time_seconds' => :'startTimeSeconds', :'end_time_seconds' => :'endTimeSeconds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 55 def self.openapi_types { :'speaker' => :'Integer', :'text' => :'String', :'confidence' => :'Float', :'start_time_seconds' => :'Float', :'end_time_seconds' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && speaker == o.speaker && text == o.text && confidence == o.confidence && start_time_seconds == o.start_time_seconds && end_time_seconds == o.end_time_seconds end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 171 def hash [speaker, text, confidence, start_time_seconds, end_time_seconds].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@confidence.nil? && @confidence > 1 invalid_properties.push('invalid value for "confidence", must be smaller than or equal to 1.') end if !@confidence.nil? && @confidence < 0 invalid_properties.push('invalid value for "confidence", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 130 131 |
# File 'lib/bandwidth-sdk/models/recording_transcription_clip.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@confidence.nil? && @confidence > 1 return false if !@confidence.nil? && @confidence < 0 true end |