Class: Bandwidth::ReferCompleteCallback

Inherits:
ApiModelBase show all
Defined in:
lib/bandwidth-sdk/models/refer_complete_callback.rb

Overview

This event is sent to the referCompleteUrl of a call's verb when the SIP REFER flow completes. On success, the call has been torn down and the BXML returned from this callback is ignored. On failure, the call remains active and the BXML returned from this callback is executed on the call.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReferCompleteCallback

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::ReferCompleteCallback` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::ReferCompleteCallback`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'event_time')
    self.event_time = attributes[:'event_time']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'call_id')
    self.call_id = attributes[:'call_id']
  end

  if attributes.key?(:'call_url')
    self.call_url = attributes[:'call_url']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'answer_time')
    self.answer_time = attributes[:'answer_time']
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'refer_call_status')
    self.refer_call_status = attributes[:'refer_call_status']
  end

  if attributes.key?(:'refer_sip_response_code')
    self.refer_sip_response_code = attributes[:'refer_sip_response_code']
  end

  if attributes.key?(:'notify_sip_response_code')
    self.notify_sip_response_code = attributes[:'notify_sip_response_code']
  end
end

Instance Attribute Details

#account_idObject

The user account associated with the call.



26
27
28
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 26

def 
  @account_id
end

#answer_timeObject

Time the call was answered, in ISO 8601 format.



49
50
51
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 49

def answer_time
  @answer_time
end

#application_idObject

The id of the application associated with the call.



29
30
31
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 29

def application_id
  @application_id
end

#call_idObject

The call id associated with the event.



40
41
42
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 40

def call_id
  @call_id
end

#call_urlObject

The URL of the call associated with the event.



43
44
45
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 43

def call_url
  @call_url
end

#directionObject

Returns the value of attribute direction.



37
38
39
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 37

def direction
  @direction
end

#event_timeObject

The approximate UTC date and time when the event was generated by the Bandwidth server, in ISO 8601 format. This may not be exactly the time of event execution.



23
24
25
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 23

def event_time
  @event_time
end

#event_typeObject

The event type, value can be one of the following: answer, bridgeComplete, bridgeTargetComplete, conferenceCreated, conferenceRedirect, conferenceMemberJoin, conferenceMemberExit, conferenceCompleted, conferenceRecordingAvailable, disconnect, dtmf, gather, initiate, machineDetectionComplete, recordingComplete, recordingAvailable, redirect, referComplete, transcriptionAvailable, transferAnswer, transferComplete, transferDisconnect.



20
21
22
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 20

def event_type
  @event_type
end

#fromObject

The provided identifier of the caller. Must be a phone number in E.164 format (e.g. +15555555555).



32
33
34
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 32

def from
  @from
end

#notify_sip_response_codeObject

(optional) The final SIP response code reported via NOTIFY (message/sipfrag body). Present only when the caller's endpoint sent a final NOTIFY (e.g. 200, 404, 486, 503). Not present on NOTIFY timeout or when the REFER was rejected before a subscription was established.



60
61
62
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 60

def notify_sip_response_code
  @notify_sip_response_code
end

#refer_call_statusObject

Returns the value of attribute refer_call_status.



54
55
56
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 54

def refer_call_status
  @refer_call_status
end

#refer_sip_response_codeObject

(optional) The SIP response code returned for the REFER request itself (e.g. 202, 405, 603). Present when a SIP response was received for the REFER.



57
58
59
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 57

def refer_sip_response_code
  @refer_sip_response_code
end

#start_timeObject

Time the call was started, in ISO 8601 format.



46
47
48
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 46

def start_time
  @start_time
end

#tagObject

(optional) The tag specified on call creation. If no tag was specified or it was previously cleared, this field will not be present.



52
53
54
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 52

def tag
  @tag
end

#toObject

The phone number that received the call, in E.164 format (e.g. +15555555555).



35
36
37
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 35

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



106
107
108
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 106

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 111

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 85

def self.attribute_map
  {
    :'event_type' => :'eventType',
    :'event_time' => :'eventTime',
    :'account_id' => :'accountId',
    :'application_id' => :'applicationId',
    :'from' => :'from',
    :'to' => :'to',
    :'direction' => :'direction',
    :'call_id' => :'callId',
    :'call_url' => :'callUrl',
    :'start_time' => :'startTime',
    :'answer_time' => :'answerTime',
    :'tag' => :'tag',
    :'refer_call_status' => :'referCallStatus',
    :'refer_sip_response_code' => :'referSipResponseCode',
    :'notify_sip_response_code' => :'notifySipResponseCode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 273

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



137
138
139
140
141
142
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 137

def self.openapi_nullable
  Set.new([
    :'answer_time',
    :'tag',
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 116

def self.openapi_types
  {
    :'event_type' => :'String',
    :'event_time' => :'Time',
    :'account_id' => :'String',
    :'application_id' => :'String',
    :'from' => :'String',
    :'to' => :'String',
    :'direction' => :'CallDirectionEnum',
    :'call_id' => :'String',
    :'call_url' => :'String',
    :'start_time' => :'Time',
    :'answer_time' => :'Time',
    :'tag' => :'String',
    :'refer_call_status' => :'ReferCallStatusEnum',
    :'refer_sip_response_code' => :'Integer',
    :'notify_sip_response_code' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event_type == o.event_type &&
      event_time == o.event_time &&
       == o. &&
      application_id == o.application_id &&
      from == o.from &&
      to == o.to &&
      direction == o.direction &&
      call_id == o.call_id &&
      call_url == o.call_url &&
      start_time == o.start_time &&
      answer_time == o.answer_time &&
      tag == o.tag &&
      refer_call_status == o.refer_call_status &&
      refer_sip_response_code == o.refer_sip_response_code &&
      notify_sip_response_code == o.notify_sip_response_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 266

def hash
  [event_type, event_time, , application_id, from, to, direction, call_id, call_url, start_time, answer_time, tag, refer_call_status, refer_sip_response_code, notify_sip_response_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
# File 'lib/bandwidth-sdk/models/refer_complete_callback.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end