Class: Bandwidth::TfvStatus

Inherits:
ApiModelBase show all
Defined in:
lib/bandwidth-sdk/models/tfv_status.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TfvStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 136

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::TfvStatus` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::TfvStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'internal_ticket_number')
    self.internal_ticket_number = attributes[:'internal_ticket_number']
  end

  if attributes.key?(:'decline_reason_description')
    self.decline_reason_description = attributes[:'decline_reason_description']
  end

  if attributes.key?(:'denial_status_code')
    self.denial_status_code = attributes[:'denial_status_code']
  end

  if attributes.key?(:'additional_denial_reasons')
    if (value = attributes[:'additional_denial_reasons']).is_a?(Array)
      self.additional_denial_reasons = value
    end
  end

  if attributes.key?(:'resubmit_allowed')
    self.resubmit_allowed = attributes[:'resubmit_allowed']
  end

  if attributes.key?(:'created_date_time')
    self.created_date_time = attributes[:'created_date_time']
  end

  if attributes.key?(:'modified_date_time')
    self.modified_date_time = attributes[:'modified_date_time']
  end

  if attributes.key?(:'submission')
    self.submission = attributes[:'submission']
  end

  if attributes.key?(:'blocked')
    self.blocked = attributes[:'blocked']
  end

  if attributes.key?(:'blocked_reason')
    self.blocked_reason = attributes[:'blocked_reason']
  end

  if attributes.key?(:'cv_token')
    self.cv_token = attributes[:'cv_token']
  end
end

Instance Attribute Details

#additional_denial_reasonsObject

An optional list of denial reasons in addition to declineReasonDescription when multiple reasons apply.



33
34
35
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 33

def additional_denial_reasons
  @additional_denial_reasons
end

#blockedObject

Whether a Toll-Free Verification is blocked. This attribute will only be defined when the number is blocked.



47
48
49
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 47

def blocked
  @blocked
end

#blocked_reasonObject

The reason why the Toll-Free Verification is blocked. This attribute will only be defined when the number is blocked.



50
51
52
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 50

def blocked_reason
  @blocked_reason
end

#created_date_timeObject

Date and time the verification request was created.



39
40
41
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 39

def created_date_time
  @created_date_time
end

#cv_tokenObject

The token provided by Campaign Verify to validate your political use case. Only required for 527 political organizations. If you are not a 527 political organization, this field should be omitted. Supplying an empty string will likely result in rejection.



53
54
55
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 53

def cv_token
  @cv_token
end

#decline_reason_descriptionObject

Explanation for why a verification request was declined.



27
28
29
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 27

def decline_reason_description
  @decline_reason_description
end

#denial_status_codeObject

Reason code for denial.



30
31
32
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 30

def denial_status_code
  @denial_status_code
end

#internal_ticket_numberObject

Unique identifier (UUID) generated by Bandwidth to assist in tracking the verification status of a toll-free number - included in all webhook payloads.



24
25
26
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 24

def internal_ticket_number
  @internal_ticket_number
end

#modified_date_timeObject

Date and time the verification request was last modified.



42
43
44
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 42

def modified_date_time
  @modified_date_time
end

#phone_numberObject

Toll-free telephone number in E.164 format.



19
20
21
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 19

def phone_number
  @phone_number
end

#resubmit_allowedObject

Whether a Toll-Free Verification request qualifies for resubmission via PUT.



36
37
38
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 36

def resubmit_allowed
  @resubmit_allowed
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 21

def status
  @status
end

#submissionObject

Returns the value of attribute submission.



44
45
46
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 44

def submission
  @submission
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



97
98
99
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 102

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 78

def self.attribute_map
  {
    :'phone_number' => :'phoneNumber',
    :'status' => :'status',
    :'internal_ticket_number' => :'internalTicketNumber',
    :'decline_reason_description' => :'declineReasonDescription',
    :'denial_status_code' => :'denialStatusCode',
    :'additional_denial_reasons' => :'additionalDenialReasons',
    :'resubmit_allowed' => :'resubmitAllowed',
    :'created_date_time' => :'createdDateTime',
    :'modified_date_time' => :'modifiedDateTime',
    :'submission' => :'submission',
    :'blocked' => :'blocked',
    :'blocked_reason' => :'blockedReason',
    :'cv_token' => :'cvToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
130
131
132
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 126

def self.openapi_nullable
  Set.new([
    :'denial_status_code',
    :'additional_denial_reasons',
    :'cv_token'
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 107

def self.openapi_types
  {
    :'phone_number' => :'String',
    :'status' => :'TfvStatusEnum',
    :'internal_ticket_number' => :'String',
    :'decline_reason_description' => :'String',
    :'denial_status_code' => :'Integer',
    :'additional_denial_reasons' => :'Array<AdditionalDenialReason>',
    :'resubmit_allowed' => :'Boolean',
    :'created_date_time' => :'Time',
    :'modified_date_time' => :'Time',
    :'submission' => :'TfvSubmissionInfo',
    :'blocked' => :'Boolean',
    :'blocked_reason' => :'String',
    :'cv_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      phone_number == o.phone_number &&
      status == o.status &&
      internal_ticket_number == o.internal_ticket_number &&
      decline_reason_description == o.decline_reason_description &&
      denial_status_code == o.denial_status_code &&
      additional_denial_reasons == o.additional_denial_reasons &&
      resubmit_allowed == o.resubmit_allowed &&
      created_date_time == o.created_date_time &&
      modified_date_time == o.modified_date_time &&
      submission == o.submission &&
      blocked == o.blocked &&
      blocked_reason == o.blocked_reason &&
      cv_token == o.cv_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 311

def hash
  [phone_number, status, internal_ticket_number, decline_reason_description, denial_status_code, additional_denial_reasons, resubmit_allowed, created_date_time, modified_date_time, submission, blocked, blocked_reason, cv_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 207

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@phone_number.nil? && @phone_number.to_s.length > 12
    invalid_properties.push('invalid value for "phone_number", the character length must be smaller than or equal to 12.')
  end

  if !@phone_number.nil? && @phone_number.to_s.length < 12
    invalid_properties.push('invalid value for "phone_number", the character length must be greater than or equal to 12.')
  end

  pattern = Regexp.new(/^\+1(800|833|844|855|866|877|888)[2-9]\d{6}$/)
  if !@phone_number.nil? && @phone_number !~ pattern
    invalid_properties.push("invalid value for \"phone_number\", must conform to the pattern #{pattern}.")
  end

  if !@cv_token.nil? && @cv_token.to_s.length > 500
    invalid_properties.push('invalid value for "cv_token", the character length must be smaller than or equal to 500.')
  end

  if !@cv_token.nil? && @cv_token.to_s.length < 0
    invalid_properties.push('invalid value for "cv_token", the character length must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
# File 'lib/bandwidth-sdk/models/tfv_status.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@phone_number.nil? && @phone_number.to_s.length > 12
  return false if !@phone_number.nil? && @phone_number.to_s.length < 12
  return false if !@phone_number.nil? && @phone_number !~ Regexp.new(/^\+1(800|833|844|855|866|877|888)[2-9]\d{6}$/)
  return false if !@cv_token.nil? && @cv_token.to_s.length > 500
  return false if !@cv_token.nil? && @cv_token.to_s.length < 0
  true
end