Class: Bandwidth::VerificationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Bandwidth::VerificationRequest
- Defined in:
- lib/bandwidth-sdk/models/verification_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_information ⇒ Object
Any additional information.
-
#age_gated_content ⇒ Object
Indicates whether the content is age-gated.
-
#business_address ⇒ Object
Returns the value of attribute business_address.
-
#business_contact ⇒ Object
Returns the value of attribute business_contact.
-
#business_dba ⇒ Object
The company ‘Doing Business As’.
-
#business_entity_type ⇒ Object
Returns the value of attribute business_entity_type.
-
#business_registration_issuing_country ⇒ Object
Returns the value of attribute business_registration_issuing_country.
-
#business_registration_number ⇒ Object
Government-issued business identifying number.
-
#business_registration_type ⇒ Object
Returns the value of attribute business_registration_type.
-
#cv_token ⇒ Object
The token provided by Campaign Verify to validate your political use case.
-
#help_message_response ⇒ Object
A message that gets sent to users requesting help.
-
#isv_reseller ⇒ Object
ISV name.
-
#message_volume ⇒ Object
Estimated monthly volume of messages from the toll-free number.
-
#opt_in_workflow ⇒ Object
Returns the value of attribute opt_in_workflow.
-
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
-
#privacy_policy_url ⇒ Object
The Toll-Free Verification request privacy policy URL.
-
#production_message_content ⇒ Object
Example of message content.
-
#terms_and_conditions_url ⇒ Object
The Toll-Free Verification request terms and conditions policy URL.
-
#use_case ⇒ Object
The category of the use case.
-
#use_case_summary ⇒ Object
A general idea of the use case and customer.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VerificationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VerificationRequest
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 169 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::VerificationRequest` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::VerificationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'business_address') self.business_address = attributes[:'business_address'] else self.business_address = nil end if attributes.key?(:'business_contact') self.business_contact = attributes[:'business_contact'] else self.business_contact = nil end if attributes.key?(:'message_volume') self. = attributes[:'message_volume'] else self. = nil end if attributes.key?(:'phone_numbers') if (value = attributes[:'phone_numbers']).is_a?(Array) self.phone_numbers = value end else self.phone_numbers = nil end if attributes.key?(:'use_case') self.use_case = attributes[:'use_case'] else self.use_case = nil end if attributes.key?(:'use_case_summary') self.use_case_summary = attributes[:'use_case_summary'] else self.use_case_summary = nil end if attributes.key?(:'production_message_content') self. = attributes[:'production_message_content'] else self. = nil end if attributes.key?(:'opt_in_workflow') self.opt_in_workflow = attributes[:'opt_in_workflow'] else self.opt_in_workflow = nil end if attributes.key?(:'additional_information') self.additional_information = attributes[:'additional_information'] end if attributes.key?(:'isv_reseller') self.isv_reseller = attributes[:'isv_reseller'] end if attributes.key?(:'privacy_policy_url') self.privacy_policy_url = attributes[:'privacy_policy_url'] end if attributes.key?(:'terms_and_conditions_url') self.terms_and_conditions_url = attributes[:'terms_and_conditions_url'] end if attributes.key?(:'business_dba') self.business_dba = attributes[:'business_dba'] end if attributes.key?(:'business_registration_number') self.business_registration_number = attributes[:'business_registration_number'] end if attributes.key?(:'business_registration_type') self.business_registration_type = attributes[:'business_registration_type'] end if attributes.key?(:'business_registration_issuing_country') self.business_registration_issuing_country = attributes[:'business_registration_issuing_country'] end if attributes.key?(:'business_entity_type') self.business_entity_type = attributes[:'business_entity_type'] else self.business_entity_type = nil end if attributes.key?(:'help_message_response') self. = attributes[:'help_message_response'] end if attributes.key?(:'age_gated_content') self.age_gated_content = attributes[:'age_gated_content'] end if attributes.key?(:'cv_token') self.cv_token = attributes[:'cv_token'] end end |
Instance Attribute Details
#additional_information ⇒ Object
Any additional information.
39 40 41 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 39 def additional_information @additional_information end |
#age_gated_content ⇒ Object
Indicates whether the content is age-gated.
66 67 68 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 66 def age_gated_content @age_gated_content end |
#business_address ⇒ Object
Returns the value of attribute business_address.
18 19 20 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 18 def business_address @business_address end |
#business_contact ⇒ Object
Returns the value of attribute business_contact.
20 21 22 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 20 def business_contact @business_contact end |
#business_dba ⇒ Object
The company ‘Doing Business As’.
51 52 53 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 51 def business_dba @business_dba end |
#business_entity_type ⇒ Object
Returns the value of attribute business_entity_type.
60 61 62 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 60 def business_entity_type @business_entity_type end |
#business_registration_issuing_country ⇒ Object
Returns the value of attribute business_registration_issuing_country.
58 59 60 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 58 def business_registration_issuing_country @business_registration_issuing_country end |
#business_registration_number ⇒ Object
Government-issued business identifying number.
54 55 56 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 54 def business_registration_number @business_registration_number end |
#business_registration_type ⇒ Object
Returns the value of attribute business_registration_type.
56 57 58 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 56 def business_registration_type @business_registration_type end |
#cv_token ⇒ Object
The token provided by Campaign Verify to validate your political use case. Only required for 527 political organizations. If you are not a 527 political organization, this field should be omitted. Supplying an empty string will likely result in rejection.
69 70 71 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 69 def cv_token @cv_token end |
#help_message_response ⇒ Object
A message that gets sent to users requesting help.
63 64 65 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 63 def @help_message_response end |
#isv_reseller ⇒ Object
ISV name.
42 43 44 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 42 def isv_reseller @isv_reseller end |
#message_volume ⇒ Object
Estimated monthly volume of messages from the toll-free number.
23 24 25 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 23 def @message_volume end |
#opt_in_workflow ⇒ Object
Returns the value of attribute opt_in_workflow.
36 37 38 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 36 def opt_in_workflow @opt_in_workflow end |
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
25 26 27 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 25 def phone_numbers @phone_numbers end |
#privacy_policy_url ⇒ Object
The Toll-Free Verification request privacy policy URL.
45 46 47 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 45 def privacy_policy_url @privacy_policy_url end |
#production_message_content ⇒ Object
Example of message content.
34 35 36 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 34 def @production_message_content end |
#terms_and_conditions_url ⇒ Object
The Toll-Free Verification request terms and conditions policy URL.
48 49 50 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 48 def terms_and_conditions_url @terms_and_conditions_url end |
#use_case ⇒ Object
The category of the use case.
28 29 30 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 28 def use_case @use_case end |
#use_case_summary ⇒ Object
A general idea of the use case and customer.
31 32 33 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 31 def use_case_summary @use_case_summary end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
120 121 122 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 120 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 125 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 94 def self.attribute_map { :'business_address' => :'businessAddress', :'business_contact' => :'businessContact', :'message_volume' => :'messageVolume', :'phone_numbers' => :'phoneNumbers', :'use_case' => :'useCase', :'use_case_summary' => :'useCaseSummary', :'production_message_content' => :'productionMessageContent', :'opt_in_workflow' => :'optInWorkflow', :'additional_information' => :'additionalInformation', :'isv_reseller' => :'isvReseller', :'privacy_policy_url' => :'privacyPolicyUrl', :'terms_and_conditions_url' => :'termsAndConditionsUrl', :'business_dba' => :'businessDba', :'business_registration_number' => :'businessRegistrationNumber', :'business_registration_type' => :'businessRegistrationType', :'business_registration_issuing_country' => :'businessRegistrationIssuingCountry', :'business_entity_type' => :'businessEntityType', :'help_message_response' => :'helpMessageResponse', :'age_gated_content' => :'ageGatedContent', :'cv_token' => :'cvToken' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 668 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 156 def self.openapi_nullable Set.new([ :'additional_information', :'isv_reseller', :'business_registration_number', :'business_registration_type', :'help_message_response', :'cv_token' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 130 def self.openapi_types { :'business_address' => :'Address', :'business_contact' => :'Contact', :'message_volume' => :'Integer', :'phone_numbers' => :'Array<String>', :'use_case' => :'String', :'use_case_summary' => :'String', :'production_message_content' => :'String', :'opt_in_workflow' => :'OptInWorkflow', :'additional_information' => :'String', :'isv_reseller' => :'String', :'privacy_policy_url' => :'String', :'terms_and_conditions_url' => :'String', :'business_dba' => :'String', :'business_registration_number' => :'String', :'business_registration_type' => :'BusinessRegistrationTypeEnum', :'business_registration_issuing_country' => :'BusinessRegistrationIssuingCountryEnum', :'business_entity_type' => :'BusinessEntityTypeEnum', :'help_message_response' => :'String', :'age_gated_content' => :'Boolean', :'cv_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 628 def ==(o) return true if self.equal?(o) self.class == o.class && business_address == o.business_address && business_contact == o.business_contact && == o. && phone_numbers == o.phone_numbers && use_case == o.use_case && use_case_summary == o.use_case_summary && == o. && opt_in_workflow == o.opt_in_workflow && additional_information == o.additional_information && isv_reseller == o.isv_reseller && privacy_policy_url == o.privacy_policy_url && terms_and_conditions_url == o.terms_and_conditions_url && business_dba == o.business_dba && business_registration_number == o.business_registration_number && business_registration_type == o.business_registration_type && business_registration_issuing_country == o.business_registration_issuing_country && business_entity_type == o.business_entity_type && == o. && age_gated_content == o.age_gated_content && cv_token == o.cv_token end |
#eql?(o) ⇒ Boolean
655 656 657 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 655 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
661 662 663 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 661 def hash [business_address, business_contact, , phone_numbers, use_case, use_case_summary, , opt_in_workflow, additional_information, isv_reseller, privacy_policy_url, terms_and_conditions_url, business_dba, business_registration_number, business_registration_type, business_registration_issuing_country, business_entity_type, , age_gated_content, cv_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 286 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @business_address.nil? invalid_properties.push('invalid value for "business_address", business_address cannot be nil.') end if @business_contact.nil? invalid_properties.push('invalid value for "business_contact", business_contact cannot be nil.') end if @message_volume.nil? invalid_properties.push('invalid value for "message_volume", message_volume cannot be nil.') end if @message_volume > 10000000 invalid_properties.push('invalid value for "message_volume", must be smaller than or equal to 10000000.') end if @message_volume < 10 invalid_properties.push('invalid value for "message_volume", must be greater than or equal to 10.') end if @phone_numbers.nil? invalid_properties.push('invalid value for "phone_numbers", phone_numbers cannot be nil.') end if @phone_numbers.length > 10 invalid_properties.push('invalid value for "phone_numbers", number of items must be less than or equal to 10.') end if @phone_numbers.length < 1 invalid_properties.push('invalid value for "phone_numbers", number of items must be greater than or equal to 1.') end if @use_case.nil? invalid_properties.push('invalid value for "use_case", use_case cannot be nil.') end if @use_case.to_s.length > 500 invalid_properties.push('invalid value for "use_case", the character length must be smaller than or equal to 500.') end if @use_case.to_s.length < 0 invalid_properties.push('invalid value for "use_case", the character length must be greater than or equal to 0.') end if @use_case_summary.nil? invalid_properties.push('invalid value for "use_case_summary", use_case_summary cannot be nil.') end if @use_case_summary.to_s.length > 500 invalid_properties.push('invalid value for "use_case_summary", the character length must be smaller than or equal to 500.') end if @use_case_summary.to_s.length < 0 invalid_properties.push('invalid value for "use_case_summary", the character length must be greater than or equal to 0.') end if @production_message_content.nil? invalid_properties.push('invalid value for "production_message_content", production_message_content cannot be nil.') end if @production_message_content.to_s.length > 500 invalid_properties.push('invalid value for "production_message_content", the character length must be smaller than or equal to 500.') end if @production_message_content.to_s.length < 0 invalid_properties.push('invalid value for "production_message_content", the character length must be greater than or equal to 0.') end if @opt_in_workflow.nil? invalid_properties.push('invalid value for "opt_in_workflow", opt_in_workflow cannot be nil.') end if !@additional_information.nil? && @additional_information.to_s.length > 500 invalid_properties.push('invalid value for "additional_information", the character length must be smaller than or equal to 500.') end if !@additional_information.nil? && @additional_information.to_s.length < 0 invalid_properties.push('invalid value for "additional_information", the character length must be greater than or equal to 0.') end if !@isv_reseller.nil? && @isv_reseller.to_s.length > 500 invalid_properties.push('invalid value for "isv_reseller", the character length must be smaller than or equal to 500.') end if !@isv_reseller.nil? && @isv_reseller.to_s.length < 0 invalid_properties.push('invalid value for "isv_reseller", the character length must be greater than or equal to 0.') end if !@business_registration_number.nil? && @business_registration_number.to_s.length > 500 invalid_properties.push('invalid value for "business_registration_number", the character length must be smaller than or equal to 500.') end if @business_entity_type.nil? invalid_properties.push('invalid value for "business_entity_type", business_entity_type cannot be nil.') end if !@help_message_response.nil? && @help_message_response.to_s.length > 500 invalid_properties.push('invalid value for "help_message_response", the character length must be smaller than or equal to 500.') end if !@cv_token.nil? && @cv_token.to_s.length > 500 invalid_properties.push('invalid value for "cv_token", the character length must be smaller than or equal to 500.') end if !@cv_token.nil? && @cv_token.to_s.length < 0 invalid_properties.push('invalid value for "cv_token", the character length must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 690 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/bandwidth-sdk/models/verification_request.rb', line 402 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @business_address.nil? return false if @business_contact.nil? return false if @message_volume.nil? return false if @message_volume > 10000000 return false if @message_volume < 10 return false if @phone_numbers.nil? return false if @phone_numbers.length > 10 return false if @phone_numbers.length < 1 return false if @use_case.nil? return false if @use_case.to_s.length > 500 return false if @use_case.to_s.length < 0 return false if @use_case_summary.nil? return false if @use_case_summary.to_s.length > 500 return false if @use_case_summary.to_s.length < 0 return false if @production_message_content.nil? return false if @production_message_content.to_s.length > 500 return false if @production_message_content.to_s.length < 0 return false if @opt_in_workflow.nil? return false if !@additional_information.nil? && @additional_information.to_s.length > 500 return false if !@additional_information.nil? && @additional_information.to_s.length < 0 return false if !@isv_reseller.nil? && @isv_reseller.to_s.length > 500 return false if !@isv_reseller.nil? && @isv_reseller.to_s.length < 0 return false if !@business_registration_number.nil? && @business_registration_number.to_s.length > 500 return false if @business_entity_type.nil? return false if !@help_message_response.nil? && @help_message_response.to_s.length > 500 return false if !@cv_token.nil? && @cv_token.to_s.length > 500 return false if !@cv_token.nil? && @cv_token.to_s.length < 0 true end |