Class: Bandwidth::Bxml::Refer
- Inherits:
-
NestableVerb
- Object
- Verb
- NestableVerb
- Bandwidth::Bxml::Refer
- Defined in:
- lib/bandwidth-sdk/models/bxml/verbs/refer.rb
Instance Method Summary collapse
-
#initialize(sip_uri = [], attributes = {}) ⇒ Refer
constructor
Initializer.
-
#set_sip_uri(sip_uri) ⇒ Object
Set the SIP URI destination for this Refer verb.
Methods inherited from NestableVerb
Methods inherited from Verb
#generate_xml, #set_attributes, #to_bxml
Constructor Details
#initialize(sip_uri = [], attributes = {}) ⇒ Refer
Initializer
7 8 9 10 11 12 13 14 15 |
# File 'lib/bandwidth-sdk/models/bxml/verbs/refer.rb', line 7 def initialize(sip_uri = [], attributes = {}) super('Refer', nil, sip_uri, attributes) @attribute_map = { refer_complete_url: 'referCompleteUrl', # Optional [String]: URL to send the Refer Complete event to and request new BXML for failure recovery. May be a relative URL. Defaults to None. refer_complete_method: 'referCompleteMethod', # Optional [String]: The HTTP method to use for the request to referCompleteUrl. GET or POST. Default value is POST. Defaults to None. tag: 'tag', # Optional [String]: A custom string that will be sent with this and all future callbacks unless overwritten by a future tag attribute or cleared. May be cleared by setting tag="". Max length 256 characters. Defaults to None. } end |
Instance Method Details
#set_sip_uri(sip_uri) ⇒ Object
Set the SIP URI destination for this Refer verb
19 20 21 |
# File 'lib/bandwidth-sdk/models/bxml/verbs/refer.rb', line 19 def set_sip_uri(sip_uri) @nested_verbs = [sip_uri] end |