Method: Bandwidth::MachineDetectionConfiguration#mode
- Defined in:
- lib/bandwidth/voice_lib/voice/models/machine_detection_configuration.rb
#mode ⇒ ModeEnum
The machine detection mode. If set to ‘async’, the detection result will be sent in a ‘machineDetectionComplete’ callback. If set to ‘sync’, the ‘answer’ callback will wait for the machine detection to complete and will include its result. Default is ‘async’.
17 18 19 |
# File 'lib/bandwidth/voice_lib/voice/models/machine_detection_configuration.rb', line 17 def mode @mode end |