Class: Bandwidth::RbmCardContent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Bandwidth::RbmCardContent
- Defined in:
- lib/bandwidth-sdk/models/rbm_card_content.rb
Overview
Must contain at least one of title, description, or media to be valid.
Instance Attribute Summary collapse
-
#description ⇒ Object
The description of the card.
-
#media ⇒ Object
Returns the value of attribute media.
-
#suggestions ⇒ Object
An array of suggested actions for the recipient that will be displayed on the rich card.
-
#title ⇒ Object
The title of the card.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RbmCardContent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RbmCardContent
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::RbmCardContent` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::RbmCardContent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'media') self.media = attributes[:'media'] end if attributes.key?(:'suggestions') if (value = attributes[:'suggestions']).is_a?(Array) self.suggestions = value end end end |
Instance Attribute Details
#description ⇒ Object
The description of the card. Must be 2000 characters or less.
23 24 25 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 23 def description @description end |
#media ⇒ Object
Returns the value of attribute media.
25 26 27 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 25 def media @media end |
#suggestions ⇒ Object
An array of suggested actions for the recipient that will be displayed on the rich card.
28 29 30 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 28 def suggestions @suggestions end |
#title ⇒ Object
The title of the card. Must be 200 characters or less.
20 21 22 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 20 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 31 def self.attribute_map { :'title' => :'title', :'description' => :'description', :'media' => :'media', :'suggestions' => :'suggestions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 51 def self.openapi_types { :'title' => :'String', :'description' => :'String', :'media' => :'RbmCardContentMedia', :'suggestions' => :'Array<MultiChannelAction>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 175 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && description == o.description && media == o.media && suggestions == o.suggestions end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 192 def hash [title, description, media, suggestions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 200 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 200.') end if !@description.nil? && @description.to_s.length > 2000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 2000.') end if !@suggestions.nil? && @suggestions.length > 4 invalid_properties.push('invalid value for "suggestions", number of items must be less than or equal to 4.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 129 |
# File 'lib/bandwidth-sdk/models/rbm_card_content.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 200 return false if !@description.nil? && @description.to_s.length > 2000 return false if !@suggestions.nil? && @suggestions.length > 4 true end |