Class: Bandwidth::TfvSubmissionInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Bandwidth::TfvSubmissionInfo
- Defined in:
- lib/bandwidth-sdk/models/tfv_submission_info.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_information ⇒ Object
Any additional information.
-
#business_address ⇒ Object
Returns the value of attribute business_address.
-
#business_contact ⇒ Object
Returns the value of attribute business_contact.
-
#business_dba ⇒ Object
The company ‘Doing Business As’.
-
#business_entity_type ⇒ Object
Returns the value of attribute business_entity_type.
-
#business_registration_issuing_country ⇒ Object
Returns the value of attribute business_registration_issuing_country.
-
#business_registration_number ⇒ Object
Government-issued business identifying number.
-
#business_registration_type ⇒ Object
Returns the value of attribute business_registration_type.
-
#isv_reseller ⇒ Object
ISV name.
-
#message_volume ⇒ Object
Estimated monthly volume of messages from the toll-free number.
-
#opt_in_workflow ⇒ Object
Returns the value of attribute opt_in_workflow.
-
#privacy_policy_url ⇒ Object
The Toll-Free Verification request privacy policy URL.
-
#production_message_content ⇒ Object
Example of message content.
-
#terms_and_conditions_url ⇒ Object
The Toll-Free Verification request terms and conditions policy URL.
-
#use_case ⇒ Object
The category of the use case.
-
#use_case_summary ⇒ Object
A general idea of the use case and customer.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TfvSubmissionInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TfvSubmissionInfo
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `Bandwidth::TfvSubmissionInfo` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Bandwidth::TfvSubmissionInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'business_address') self.business_address = attributes[:'business_address'] end if attributes.key?(:'business_contact') self.business_contact = attributes[:'business_contact'] end if attributes.key?(:'message_volume') self. = attributes[:'message_volume'] end if attributes.key?(:'use_case') self.use_case = attributes[:'use_case'] end if attributes.key?(:'use_case_summary') self.use_case_summary = attributes[:'use_case_summary'] end if attributes.key?(:'production_message_content') self. = attributes[:'production_message_content'] end if attributes.key?(:'opt_in_workflow') self.opt_in_workflow = attributes[:'opt_in_workflow'] end if attributes.key?(:'additional_information') self.additional_information = attributes[:'additional_information'] end if attributes.key?(:'isv_reseller') self.isv_reseller = attributes[:'isv_reseller'] end if attributes.key?(:'privacy_policy_url') self.privacy_policy_url = attributes[:'privacy_policy_url'] end if attributes.key?(:'terms_and_conditions_url') self.terms_and_conditions_url = attributes[:'terms_and_conditions_url'] end if attributes.key?(:'business_dba') self.business_dba = attributes[:'business_dba'] end if attributes.key?(:'business_registration_number') self.business_registration_number = attributes[:'business_registration_number'] end if attributes.key?(:'business_registration_type') self.business_registration_type = attributes[:'business_registration_type'] end if attributes.key?(:'business_registration_issuing_country') self.business_registration_issuing_country = attributes[:'business_registration_issuing_country'] end if attributes.key?(:'business_entity_type') self.business_entity_type = attributes[:'business_entity_type'] end end |
Instance Attribute Details
#additional_information ⇒ Object
Any additional information.
37 38 39 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 37 def additional_information @additional_information end |
#business_address ⇒ Object
Returns the value of attribute business_address.
18 19 20 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 18 def business_address @business_address end |
#business_contact ⇒ Object
Returns the value of attribute business_contact.
20 21 22 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 20 def business_contact @business_contact end |
#business_dba ⇒ Object
The company ‘Doing Business As’.
49 50 51 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 49 def business_dba @business_dba end |
#business_entity_type ⇒ Object
Returns the value of attribute business_entity_type.
58 59 60 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 58 def business_entity_type @business_entity_type end |
#business_registration_issuing_country ⇒ Object
Returns the value of attribute business_registration_issuing_country.
56 57 58 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 56 def business_registration_issuing_country @business_registration_issuing_country end |
#business_registration_number ⇒ Object
Government-issued business identifying number.
52 53 54 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 52 def business_registration_number @business_registration_number end |
#business_registration_type ⇒ Object
Returns the value of attribute business_registration_type.
54 55 56 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 54 def business_registration_type @business_registration_type end |
#isv_reseller ⇒ Object
ISV name.
40 41 42 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 40 def isv_reseller @isv_reseller end |
#message_volume ⇒ Object
Estimated monthly volume of messages from the toll-free number.
23 24 25 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 23 def @message_volume end |
#opt_in_workflow ⇒ Object
Returns the value of attribute opt_in_workflow.
34 35 36 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 34 def opt_in_workflow @opt_in_workflow end |
#privacy_policy_url ⇒ Object
The Toll-Free Verification request privacy policy URL.
43 44 45 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 43 def privacy_policy_url @privacy_policy_url end |
#production_message_content ⇒ Object
Example of message content.
32 33 34 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 32 def @production_message_content end |
#terms_and_conditions_url ⇒ Object
The Toll-Free Verification request terms and conditions policy URL.
46 47 48 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 46 def terms_and_conditions_url @terms_and_conditions_url end |
#use_case ⇒ Object
The category of the use case.
26 27 28 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 26 def use_case @use_case end |
#use_case_summary ⇒ Object
A general idea of the use case and customer.
29 30 31 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 29 def use_case_summary @use_case_summary end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
105 106 107 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 105 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 110 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 83 def self.attribute_map { :'business_address' => :'businessAddress', :'business_contact' => :'businessContact', :'message_volume' => :'messageVolume', :'use_case' => :'useCase', :'use_case_summary' => :'useCaseSummary', :'production_message_content' => :'productionMessageContent', :'opt_in_workflow' => :'optInWorkflow', :'additional_information' => :'additionalInformation', :'isv_reseller' => :'isvReseller', :'privacy_policy_url' => :'privacyPolicyUrl', :'terms_and_conditions_url' => :'termsAndConditionsUrl', :'business_dba' => :'businessDba', :'business_registration_number' => :'businessRegistrationNumber', :'business_registration_type' => :'businessRegistrationType', :'business_registration_issuing_country' => :'businessRegistrationIssuingCountry', :'business_entity_type' => :'businessEntityType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 455 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 141 142 143 144 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 137 def self.openapi_nullable Set.new([ :'additional_information', :'isv_reseller', :'business_registration_number', :'business_registration_type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 115 def self.openapi_types { :'business_address' => :'Address', :'business_contact' => :'Contact', :'message_volume' => :'Integer', :'use_case' => :'String', :'use_case_summary' => :'String', :'production_message_content' => :'String', :'opt_in_workflow' => :'OptInWorkflow', :'additional_information' => :'String', :'isv_reseller' => :'String', :'privacy_policy_url' => :'String', :'terms_and_conditions_url' => :'String', :'business_dba' => :'String', :'business_registration_number' => :'String', :'business_registration_type' => :'BusinessRegistrationTypeEnum', :'business_registration_issuing_country' => :'BusinessRegistrationIssuingCountryEnum', :'business_entity_type' => :'BusinessEntityTypeEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 419 def ==(o) return true if self.equal?(o) self.class == o.class && business_address == o.business_address && business_contact == o.business_contact && == o. && use_case == o.use_case && use_case_summary == o.use_case_summary && == o. && opt_in_workflow == o.opt_in_workflow && additional_information == o.additional_information && isv_reseller == o.isv_reseller && privacy_policy_url == o.privacy_policy_url && terms_and_conditions_url == o.terms_and_conditions_url && business_dba == o.business_dba && business_registration_number == o.business_registration_number && business_registration_type == o.business_registration_type && business_registration_issuing_country == o.business_registration_issuing_country && business_entity_type == o.business_entity_type end |
#eql?(o) ⇒ Boolean
442 443 444 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 442 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
448 449 450 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 448 def hash [business_address, business_contact, , use_case, use_case_summary, , opt_in_workflow, additional_information, isv_reseller, privacy_policy_url, terms_and_conditions_url, business_dba, business_registration_number, business_registration_type, business_registration_issuing_country, business_entity_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 229 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@message_volume.nil? && @message_volume > 10000000 invalid_properties.push('invalid value for "message_volume", must be smaller than or equal to 10000000.') end if !@message_volume.nil? && @message_volume < 10 invalid_properties.push('invalid value for "message_volume", must be greater than or equal to 10.') end if !@use_case.nil? && @use_case.to_s.length > 500 invalid_properties.push('invalid value for "use_case", the character length must be smaller than or equal to 500.') end if !@use_case.nil? && @use_case.to_s.length < 0 invalid_properties.push('invalid value for "use_case", the character length must be greater than or equal to 0.') end if !@use_case_summary.nil? && @use_case_summary.to_s.length > 500 invalid_properties.push('invalid value for "use_case_summary", the character length must be smaller than or equal to 500.') end if !@use_case_summary.nil? && @use_case_summary.to_s.length < 0 invalid_properties.push('invalid value for "use_case_summary", the character length must be greater than or equal to 0.') end if !@production_message_content.nil? && @production_message_content.to_s.length > 500 invalid_properties.push('invalid value for "production_message_content", the character length must be smaller than or equal to 500.') end if !@production_message_content.nil? && @production_message_content.to_s.length < 0 invalid_properties.push('invalid value for "production_message_content", the character length must be greater than or equal to 0.') end if !@additional_information.nil? && @additional_information.to_s.length > 500 invalid_properties.push('invalid value for "additional_information", the character length must be smaller than or equal to 500.') end if !@additional_information.nil? && @additional_information.to_s.length < 0 invalid_properties.push('invalid value for "additional_information", the character length must be greater than or equal to 0.') end if !@isv_reseller.nil? && @isv_reseller.to_s.length > 500 invalid_properties.push('invalid value for "isv_reseller", the character length must be smaller than or equal to 500.') end if !@isv_reseller.nil? && @isv_reseller.to_s.length < 0 invalid_properties.push('invalid value for "isv_reseller", the character length must be greater than or equal to 0.') end if !@business_registration_number.nil? && @business_registration_number.to_s.length > 500 invalid_properties.push('invalid value for "business_registration_number", the character length must be smaller than or equal to 500.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 477 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/bandwidth-sdk/models/tfv_submission_info.rb', line 289 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@message_volume.nil? && @message_volume > 10000000 return false if !@message_volume.nil? && @message_volume < 10 return false if !@use_case.nil? && @use_case.to_s.length > 500 return false if !@use_case.nil? && @use_case.to_s.length < 0 return false if !@use_case_summary.nil? && @use_case_summary.to_s.length > 500 return false if !@use_case_summary.nil? && @use_case_summary.to_s.length < 0 return false if !@production_message_content.nil? && @production_message_content.to_s.length > 500 return false if !@production_message_content.nil? && @production_message_content.to_s.length < 0 return false if !@additional_information.nil? && @additional_information.to_s.length > 500 return false if !@additional_information.nil? && @additional_information.to_s.length < 0 return false if !@isv_reseller.nil? && @isv_reseller.to_s.length > 500 return false if !@isv_reseller.nil? && @isv_reseller.to_s.length < 0 return false if !@business_registration_number.nil? && @business_registration_number.to_s.length > 500 true end |